@@ -15,6 +15,7 @@ from neutron_lib.api.definitions import agent
 from neutron_lib.api.definitions import allowedaddresspairs
 from neutron_lib.api.definitions import auto_allocated_topology
 from neutron_lib.api.definitions import availability_zone
+from neutron_lib.api.definitions import availability_zone_filter
 from neutron_lib.api.definitions import bgpvpn
 from neutron_lib.api.definitions import bgpvpn_routes_control
 from neutron_lib.api.definitions import bgpvpn_stdattrs
@@ -39,6 +40,7 @@ from neutron_lib.api.definitions import firewall_v2
 from neutron_lib.api.definitions import firewallrouterinsertion
 from neutron_lib.api.definitions import flavors
 from neutron_lib.api.definitions import floating_ip_port_forwarding
+from neutron_lib.api.definitions import floatingip_pools
 from neutron_lib.api.definitions import flowclassifier
 from neutron_lib.api.definitions import ip_allocation
 from neutron_lib.api.definitions import ip_substring_port_filtering
@@ -58,6 +60,7 @@ from neutron_lib.api.definitions import network_mtu
 from neutron_lib.api.definitions import network_mtu_writable
 from neutron_lib.api.definitions import pagination
 from neutron_lib.api.definitions import port
+from neutron_lib.api.definitions import port_mac_address_regenerate
 from neutron_lib.api.definitions import port_security
 from neutron_lib.api.definitions import portbindings
 from neutron_lib.api.definitions import portbindings_extended
@@ -71,6 +74,7 @@ from neutron_lib.api.definitions import revisionifmatch
 from neutron_lib.api.definitions import router_availability_zone
 from neutron_lib.api.definitions import router_interface_fip
 from neutron_lib.api.definitions import routerservicetype
+from neutron_lib.api.definitions import security_groups_port_filtering
 from neutron_lib.api.definitions import segment
 from neutron_lib.api.definitions import servicetype
 from neutron_lib.api.definitions import sfc
@@ -95,6 +99,7 @@ _ALL_API_DEFINITIONS = {
     allowedaddresspairs,
     auto_allocated_topology,
     availability_zone,
+    availability_zone_filter,
     bgpvpn,
     bgpvpn_routes_control,
     bgpvpn_stdattrs,
@@ -119,6 +124,7 @@ _ALL_API_DEFINITIONS = {
     fip_port_details,
     flavors,
     floating_ip_port_forwarding,
+    floatingip_pools,
     ip_allocation,
     ip_substring_port_filtering,
     l2_adjacency,
@@ -138,6 +144,7 @@ _ALL_API_DEFINITIONS = {
     network_mtu_writable,
     pagination,
     port,
+    port_mac_address_regenerate,
     port_security,
     portbindings,
     portbindings_extended,
@@ -151,6 +158,7 @@ _ALL_API_DEFINITIONS = {
     router_availability_zone,
     router_interface_fip,
     routerservicetype,
+    security_groups_port_filtering,
     segment,
     servicetype,
     sfc,
